package com.ruoyi.mall.service;

import java.util.List;

import com.ruoyi.mall.domain.Bo.MallSchoolAppraiseExcelBo;
import com.ruoyi.mall.domain.MallSchoolAppraise;

/**
 * 院校评估Service接口
 * 
 * @author lsm
 * @date 2023-10-19
 */
public interface IMallSchoolAppraiseService 
{
    /** 导入importSchoolAppraise
     *
     * @param list
     * @param updateSupport
     * @param operName
     * @return
     */
     public String importSchoolAppraise(List<MallSchoolAppraiseExcelBo> list, boolean updateSupport, String operName);


    /**
     * 查询院校评估
     * 
     * @param appraiseId 院校评估主键
     * @return 院校评估
     */
    public MallSchoolAppraise selectMallSchoolAppraiseByAppraiseId(Long appraiseId);

    /**
     * 查询院校评估列表
     * 
     * @param mallSchoolAppraise 院校评估
     * @return 院校评估集合
     */
    public List<MallSchoolAppraise> selectMallSchoolAppraiseList(MallSchoolAppraise mallSchoolAppraise);

    /**
     * 新增院校评估
     * 
     * @param mallSchoolAppraise 院校评估
     * @return 结果
     */
    public int insertMallSchoolAppraise(MallSchoolAppraise mallSchoolAppraise);

    /**
     * 修改院校评估
     * 
     * @param mallSchoolAppraise 院校评估
     * @return 结果
     */
    public int updateMallSchoolAppraise(MallSchoolAppraise mallSchoolAppraise);

    /**
     * 批量删除院校评估
     * 
     * @param appraiseIds 需要删除的院校评估主键集合
     * @return 结果
     */
    public int deleteMallSchoolAppraiseByAppraiseIds(Long[] appraiseIds);

    /**
     * 删除院校评估信息
     * 
     * @param appraiseId 院校评估主键
     * @return 结果
     */
    public int deleteMallSchoolAppraiseByAppraiseId(Long appraiseId);
}
